@@ -374,7 +374,12 @@ class XtpMdApi(MdApi):
             gateway_name=self.gateway_name
         )
 
+
         if contract.product != Product.OPTION:
+            if contract.product == Product.EQUITY:
+                contract.full_symbol = f"STOCK:CN:{contract.symbol}"
+                contract.broker_symbol=contract.symbol
+
             self.gateway.on_contract(contract)
 
         symbol_contract_map[contract.vt_symbol] = contract
@@ -676,6 +681,9 @@ class XtpTdApi(TdApi):
             contract.option_strike, data["contract_id"]
         )
 
+        #if contract.product != Product.BOND:
+        #    contract.full_symbol=f"STOCK:CN:{data['symbol']}"
+
         self.gateway.on_contract(contract)
         symbol_contract_map[contract.vt_symbol] = contract
 
